From 4a5a7439265bd671a14284025b2fac3c6932930b Mon Sep 17 00:00:00 2001
From: Peter Eisentraut <peter@eisentraut.org>
Date: Wed, 13 Apr 2022 11:18:46 +0200
Subject: [PATCH 3/5] Fix warnings about deprecated features

---
 contrib/dblink/meson.build        |  2 +-
 contrib/postgres_fdw/meson.build  |  2 +-
 meson.build                       | 26 +++++++++++++-------------
 src/bin/pg_basebackup/meson.build |  8 ++++----
 4 files changed, 19 insertions(+), 19 deletions(-)

diff --git a/contrib/dblink/meson.build b/contrib/dblink/meson.build
index af277b9600..02e6a85a15 100644
--- a/contrib/dblink/meson.build
+++ b/contrib/dblink/meson.build
@@ -24,5 +24,5 @@ regress_tests += {
   'sql': [
     'dblink',
   ],
-  'regress_args': ['--dlpath', meson.build_root() / 'src/test/regress'],
+  'regress_args': ['--dlpath', meson.project_build_root() / 'src/test/regress'],
 }
diff --git a/contrib/postgres_fdw/meson.build b/contrib/postgres_fdw/meson.build
index 507d01448b..9e8a95ddc5 100644
--- a/contrib/postgres_fdw/meson.build
+++ b/contrib/postgres_fdw/meson.build
@@ -27,5 +27,5 @@ regress_tests += {
   'sql': [
     'postgres_fdw'
   ],
-  'regress_args': ['--dlpath', meson.build_root() / 'src/test/regress'],
+  'regress_args': ['--dlpath', meson.project_build_root() / 'src/test/regress'],
 }
diff --git a/meson.build b/meson.build
index adb6a5666c..9df1c85d51 100644
--- a/meson.build
+++ b/meson.build
@@ -2,7 +2,7 @@ project('postgresql',
   ['c'],
   version: '15devel',
   license: 'PostgreSQL',
-  meson_version: '>=0.54',
+  meson_version: '>=0.56',
   default_options: [
     'warning_level=2',
     'b_pie=true',
@@ -358,7 +358,7 @@ if not llvmopt.disabled()
 
     if ccache.found()
       llvm_irgen_command = ccache
-      llvm_irgen_args = [clang.path()] + llvm_irgen_args
+      llvm_irgen_args = [clang.full_path()] + llvm_irgen_args
     else
       llvm_irgen_command = clang
     endif
@@ -1935,7 +1935,7 @@ endif
 ###
 
 rc_cdata = configuration_data()
-rc_cdata.set_quoted('ICO', meson.source_root() / 'src' / 'port' / 'win32.ico')
+rc_cdata.set_quoted('ICO', meson.project_source_root() / 'src' / 'port' / 'win32.ico')
 
 rc_lib_cdata = rc_cdata
 rc_lib_cdata.set('VFT_TYPE', 'VFT_DLL')
@@ -2074,7 +2074,7 @@ if fs.is_absolute(get_option('prefix'))
 endif
 
 # DESTDIR for the installation used to run tests in
-test_install_destdir = meson.build_root() / 'tmp_install/'
+test_install_destdir = meson.project_build_root() / 'tmp_install/'
 # DESTDIR + prefix appropriately munged
 test_install_location = test_install_destdir / test_prefix
 
@@ -2086,7 +2086,7 @@ test('tmp_install',
     is_parallel: false,
     suite: ['setup'])
 
-test_result_dir = meson.build_root() / 'testrun'
+test_result_dir = meson.project_build_root() / 'testrun'
 
 
 # XXX: pg_regress doesn't assign unique ports on windows. To avoid the
@@ -2150,9 +2150,9 @@ foreach t : regress_tests
     'depends': test_deps + t.get('deps', []),
     'env': env,
     'args': [
-      testwrap.path(),
+      testwrap.full_path(),
       t['sd'],
-      meson.build_root(),
+      meson.project_build_root(),
       t['bd'],
       t['name'],
       'pg_regress',
@@ -2207,9 +2207,9 @@ foreach t : isolation_tests
     'depends': test_deps + t.get('deps', []),
     'env': env,
     'args': [
-      testwrap.path(),
+      testwrap.full_path(),
       t['sd'],
-      meson.build_root(),
+      meson.project_build_root(),
       t['bd'],
       t['name'],
       'isolation',
@@ -2244,8 +2244,8 @@ if get_option('enable-tap-tests')
 
   foreach t : tap_tests
     test_command = [
-      perl.path(),
-      '-I', meson.source_root() / 'src/test/perl',
+      perl.full_path(),
+      '-I', meson.project_source_root() / 'src/test/perl',
       '-I', t['sd'],
     ]
 
@@ -2272,9 +2272,9 @@ if get_option('enable-tap-tests')
         sh,
         kwargs: test_kwargs,
         args: [
-          testwrap.path(),
+          testwrap.full_path(),
           t['sd'],
-          meson.build_root(),
+          meson.project_build_root(),
           t['bd'],
           t['name'],
           onetap,
diff --git a/src/bin/pg_basebackup/meson.build b/src/bin/pg_basebackup/meson.build
index 9bd45585a9..b5617b818f 100644
--- a/src/bin/pg_basebackup/meson.build
+++ b/src/bin/pg_basebackup/meson.build
@@ -42,10 +42,10 @@ tap_tests += {
   'name' : 'pg_basebackup',
   'sd': meson.current_source_dir(),
   'bd': meson.current_build_dir(),
-  'env': {'GZIP_PROGRAM': gzip.path(),
-          'TAR': tar.path(),
-          'LZ4': program_lz4.found() ? program_lz4.path() : '',
-          'ZSTD': program_zstd.found() ? program_zstd.path() : ''},
+  'env': {'GZIP_PROGRAM': gzip.full_path(),
+          'TAR': tar.full_path(),
+          'LZ4': program_lz4.found() ? program_lz4.full_path() : '',
+          'ZSTD': program_zstd.found() ? program_zstd.full_path() : ''},
   'tests': [
     't/010_pg_basebackup.pl',
     't/020_pg_receivewal.pl',
-- 
2.35.1

